[PVFS2-CVS] commit by robl in pvfs2-1/test/automated: testscrpt.sh

CVS commit program cvs at parl.clemson.edu
Tue Jun 21 19:42:22 EDT 2005


Update of /projects/cvsroot/pvfs2-1/test/automated
In directory parlweb:/tmp/cvs-serv3971

Modified Files:
	testscrpt.sh 
Log Message:
let nightly pvfs2 servers co-exist with other pvfs2-servers by running on a
wierder port


Index: testscrpt.sh
===================================================================
RCS file: /projects/cvsroot/pvfs2-1/test/automated/testscrpt.sh,v
diff -u -w -p -u -r1.3 -r1.4
--- testscrpt.sh	21 Jun 2005 22:00:46 -0000	1.3
+++ testscrpt.sh	21 Jun 2005 22:42:22 -0000	1.4
@@ -12,7 +12,7 @@
 
 PVFS2_SRC=${HOME}/src/pvfs2
 PVFS2_DEST=/tmp/pvfs2-nightly
-PVFS2_MOUNTPOINT=/pvfs2
+PVFS2_MOUNTPOINT=/pvfs2-nightly
 TESTS=${HOME}/src/benchmarks
 STARTTIME=`date +%s`
 TINDERSCRIPT=$(cd `dirname $0`; pwd)/tinder-pvfs2-status
@@ -43,7 +43,7 @@ setup_pvfs2() {
 	pushd .
 	cd $PVFS2_DEST
 	INSTALL-pvfs2/bin/pvfs2-genconfig fs.conf server.conf \
-		--protocol tcp --port 3334 \
+		--protocol tcp --port 3399 \
 		--ioservers `hostname -s` --metaservers `hostname -s` \
 		--storage ${PVFS2_DEST}/STORAGE-pvfs2 \
 		--logfile=${PVFS2_DEST}/pvfs2-server.log --quiet
@@ -141,7 +141,7 @@ test_iozone() {
 ${TINDERSCRIPT} ${TESTNAME} building $STARTTIME </dev/null
 
 # compile and install
-#pull_and_build_pvfs2  || buildfail
+pull_and_build_pvfs2  || buildfail
 
 teardown_vfs && teardown_pvfs2
 
@@ -161,8 +161,8 @@ nr_passed=0
 nr_failed=0
 failure_logs=""   # a space-delimited list of logs that failed
 
-for t in test_ping test_cp test_failure ; do
-#for t in test_ping test_cp test_failure test_bonnie test_iozone; do
+for t in test_ping test_cp test_failure test_shelltest; do
+#for t in test_ping test_cp test_shelltest test_bonnie test_iozone; do
 	$t > $t.log 2>&1
 	if [ $? == 0 ] ; then 
 		nr_passed=$((nr_passed + 1))



More information about the PVFS2-CVS mailing list